==> cxf-testutils-2.0.6.10-fuse-sources.jar: org/apache/type_test/types1/DerivedStructBaseEmpty.java <==

package org.apache.type_test.types1;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DerivedStructBaseEmpty complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DerivedStructBaseEmpty">
 *   &lt;complexContent>
 *     &lt;extension base="{http://apache.org/type_test/types1}EmptyStruct">
 *       &lt;sequence>
 *         &lt;element name="varStringExt" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="varFloatExt" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *       &lt;/sequence>
 *       &lt;attribute name="attrString" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DerivedStructBaseEmpty", propOrder = {
    "varStringExt",
    "varFloatExt"
})
public class DerivedStructBaseEmpty
    extends EmptyStruct
{

    @XmlElement(namespace = "http://apache.org/type_test/types1", required = true)
    protected String varStringExt;
    @XmlElement(namespace = "http://apache.org/type_test/types1")
    protected float varFloatExt;
    @XmlAttribute
    protected String attrString;

    /**
     * Gets the value of the varStringExt property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarStringExt() {
        return varStringExt;
    }

    /**
     * Sets the value of the varStringExt property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarStringExt(String value) {
        this.varStringExt = value;
    }

    /**
     * Gets the value of the varFloatExt property.
     * 
     */
    public float getVarFloatExt() {
        return varFloatExt;
    }

    /**
     * Sets the value of the varFloatExt property.
     * 
     */
    public void setVarFloatExt(float value) {
        this.varFloatExt = value;
    }

    /**
     * Gets the value of the attrString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAttrString() {
        return attrString;
    }

    /**
     * Sets the value of the attrString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAttrString(String value) {
        this.attrString = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/types1/DerivedStructBaseEmpty.java <==

package org.apache.type_test.types1;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DerivedStructBaseEmpty complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="DerivedStructBaseEmpty">
 *   &lt;complexContent>
 *     &lt;extension base="{http://apache.org/type_test/types1}EmptyStruct">
 *       &lt;sequence>
 *         &lt;element name="varStringExt" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="varFloatExt" type="{http://www.w3.org/2001/XMLSchema}float"/>
 *       &lt;/sequence>
 *       &lt;attribute name="attrString" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "DerivedStructBaseEmpty", propOrder = {
    "varStringExt",
    "varFloatExt"
})
public class DerivedStructBaseEmpty
    extends EmptyStruct
{

    @XmlElement(required = true)
    protected String varStringExt;
    protected float varFloatExt;
    @XmlAttribute
    protected String attrString;

    /**
     * Gets the value of the varStringExt property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVarStringExt() {
        return varStringExt;
    }

    /**
     * Sets the value of the varStringExt property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVarStringExt(String value) {
        this.varStringExt = value;
    }

    /**
     * Gets the value of the varFloatExt property.
     * 
     */
    public float getVarFloatExt() {
        return varFloatExt;
    }

    /**
     * Sets the value of the varFloatExt property.
     * 
     */
    public void setVarFloatExt(float value) {
        this.varFloatExt = value;
    }

    /**
     * Gets the value of the attrString property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAttrString() {
        return attrString;
    }

    /**
     * Sets the value of the attrString property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAttrString(String value) {
        this.attrString = value;
    }

}
